==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar \"%s\"" : "%s ha publicado el calendario \"%s\"",
    "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Cancelando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no dio acceso al calendario (error HTTP {%s})",
    "Error connecting to remote server" : "Error al conectar con el servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al solicitar recurso al servidor remoto. Esto puede estar relacionado con un error de certificado",
    "Error requesting resource on remote server" : "Error al pedir recurso en servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Habitación",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No asistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está en una zona horaria desconocida ({tz}), volviendo a UTC",
    "Please create a calendar first." : "Por favor, cree primero un calendario.",
    "New event" : "Nuevo evento",
    "CalDAV address for clients" : "Dirección CalDAV para los clientes",
    "Error saving WebCal-calendar" : "Error salvando Calendario-WebCal",
    "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
    "EMail has been sent." : "El correo electrónico ha sido envidado.",
    "There was an issue while sending your EMail." : "Ha habido un problema en el envío de su correo electrónico.",
    "group" : "grupo",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solamente ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Please add a title!" : "¡Por favor añade un título!",
    "Please select a calendar!" : "¡Por favor selecciona un calendario!",
    "The event ends before it starts!" : "¡El evento termina antes de que incie!",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después de",
    "How about getting started by importing some calendars?" : "¿Qué le parece empezar importando algún calendario?",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personal",
    "Audio" : "Audio",
    "E Mail" : "Correo electrónico",
    "Pop up" : "Ventana emergente",
    "sec" : "seg.",
    "min" : "mín.",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "comienzo",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importado exitosamente",
    "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} errores",
    "Audio alarm" : "Sonido de alarma",
    "Pop-up" : "Ventana emergente",
    "E-Mail" : "Correo electrónico",
    "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Error grave en el proxy webcal. Por favor, póngase en contacto con el administrador para más información.",
    "Title of the Event" : "Título del evento",
    "Starts" : "Comienza",
    "Ends" : "Finaliza",
    "All day Event" : "Todo el día",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Event status" : "Estado del evento",
    "Visibility when sharing" : "Visibilidad cuando se comparte",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
    "Hello," : "Hola.",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Queremos informarle de que %s ha publicado el calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Pincha aquí para obtener acceso a esto",
    "Cheers!" : "¡Saludos!",
    "We wanted to inform you that %s has published the calendar %s." : "Queremos informarle de que %s ha publicado el calendario %s.",
    "Click on the link below to access it" : "Pincha en el enlace de abajo para tener acceso a esto",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Debido a un bug de upstream, el calendario no soporta la funcionalidad de asset pipeline",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
    "Share Calendar" : "Compartir calendario",
    "Shared" : "Compartido",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Enlace",
    "iCal link" : "enlace iCal",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "Share link" : "Enlace compartido",
    "Public access" : "Acceso público",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "New Calendar" : "Nuevo calendario",
    "Name" : "Nombre",
    "New Subscription" : "Nueva suscripción",
    "Go back" : "Atrás",
    "Go forward" : "Adelante",
    "Calendar does not exist" : "El calendario no existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "¿Quizás el enlace está equivocado o el calendario dejó de ser compartido?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar evento",
    "Save Event" : "Guardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Add" : "Añadir",
    "E-Mail address of attendee" : "Correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su correo electrónico en la configuración de su cuenta para agregar asistentes",
    "from" : "desde",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
    "Reset repeating rule" : "Reinicializar regla de repetición",
    "Repeat every ..." : "Repetir cada...",
    "end repeat ..." : "finalizar Repetir ...",
    "times" : "veces",
    "Import Calendars" : "Importar calendario",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "File is empty" : "El archivo está vacío",
    "Import scheduled" : "Importar horario",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
    "Embed" : "Insertar",
    "IFrame to integrate" : "IFrame para insertar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Ajustes & importar",
    "Skip simple event editor" : "Omitir el editor de evento único",
    "Show week numbers" : "Mostrar numero de semana",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se seleccionó un calendario para importar",
    "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX",
    "Subscribe" : "Suscribirse"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola.",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte de  que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Recipient" : "Destinatario",
    "Too many redirects. Aborting ..." : "Demasiadas redirecciones. Cancelando...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El servidor remoto no dio acceso al calendario (error HTTP {%s})",
    "Error connecting to remote server" : "Error al conectar con el servidor remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Error al solicitar recurso al servidor remoto. Esto puede estar relacionado con un error de certificado",
    "Error requesting resource on remote server" : "Error al pedir recurso en servidor remoto",
    "Individual" : "Individual",
    "Group" : "Grupo",
    "Resource" : "Recurso",
    "Room" : "Habitación",
    "Unknown" : "Desconocido",
    "Required" : "Requerido",
    "Optional" : "Opcional",
    "Does not attend" : "No asistir",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Está en una zona horaria desconocida ({tz}), volviendo a UTC",
    "Please create a calendar first." : "Por favor, cree primero un calendario.",
    "New event" : "Nuevo evento",
    "CalDAV address for clients" : "Dirección CalDAV para los clientes",
    "Error saving WebCal-calendar" : "Error salvando Calendario-WebCal",
    "WebDAV address for subscriptions" : "Dirección WebDAV para los subscriptores",
    "Email has been sent." : "Se ha enviado un correo electrónico.",
    "There was an issue while sending your email." : "Hubo un problema al enviar tu correo.",
    "group" : "grupo",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Repeating" : "Repetición",
    "When shared show full event" : "Mostrar el evento completo al compartir",
    "When shared show only busy" : "Mostrar solamente ocupado al compartir",
    "When shared hide this event" : "Ocultar este evento al compartir",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Please add a title." : "Por favor, añade un título.",
    "Please select a calendar." : "Por favor, selecciona un calendario.",
    "The event can not end before it starts." : "El evento no puede terminar antes de empezar.",
    "Global" : "Global",
    "None" : "Ninguno",
    "Every day" : "Cada día",
    "Every week" : "Cada semana",
    "Every month" : "Cada mes",
    "Every year" : "Cada año",
    "never" : "nunca",
    "after" : "después de",
    "How about getting started by importing some calendars?" : "¿Qué le parece empezar importando algún calendario?",
    "At time of event" : "A la hora del evento",
    "5 minutes before" : "5 minutos antes",
    "10 minutes before" : "10 minutos antes",
    "15 minutes before" : "15 minutos antes",
    "30 minutes before" : "30 minutos antes",
    "1 hour before" : "1 hora antes",
    "2 hours before" : "2 horas antes",
    "Custom" : "Personal",
    "Audio" : "Audio",
    "Email" : "Correo electrónico",
    "Pop-up" : "Ventana emergente",
    "sec" : "seg.",
    "min" : "min.",
    "hours" : "horas",
    "days" : "días",
    "week" : "semana",
    "before" : "antes",
    "start" : "comienzo",
    "end" : "fin",
    "Editing reminders of unknown type not supported." : "La edición de recordatorios de tipo desconocido no tiene respaldo.",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Successfully imported" : "Importado exitosamente",
    "Partially imported, 1 failure" : "Parcialmente importardo, 1 error",
    "Partially imported, {n} failures" : "Parcialmente importado, {n} errores",
    "Audio alarm" : "Sonido de alarma",
    "{type} {time} before the event starts" : "{type} {time} antes de que inicie el evento",
    "{type} {time} before the event ends" : "{type} {time} antes de que termine el evento",
    "{type} {time} after the event starts" : "{type} {time} después de que inicie el evento",
    "{type} {time} after the event ends" : "{type} {time} después de que termine el evento",
    "{type} at the event's start" : "{type} al inicio del evento",
    "{type} at the event's end" : "{type} al final del evento",
    "{type} at {time}" : "{type} a {time}",
    "{calendar} shared by {owner}" : "{calendar} compartido por {owner}",
    "Please enter a valid WebCal-URL" : "Por favor introduzca una URL valida WebCal",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Error grave en el proxy webcal. Por favor, póngase en contacto con el administrador para más información.",
    "Title of the Event" : "Título del evento",
    "Starts" : "Comienza",
    "Ends" : "Finaliza",
    "All day Event" : "Todo el día",
    "Delete" : "Eliminar",
    "Cancel" : "Cancelar",
    "More ..." : "Más ...",
    "Create" : "Crear",
    "Update" : "Actualizar",
    "Close" : "Cerrar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Event status" : "Estado del evento",
    "Visibility when sharing" : "Visibilidad cuando se comparte",
    "Export" : "Exportar",
    "%s has published the calendar %s" : "%s ha publicado el calendario %s",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Queremos informarle de que %s ha publicado el calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Pincha aquí para obtener acceso a esto",
    "We wanted to inform you that %s has published the calendar %s." : "Queremos informarle de que %s ha publicado el calendario %s.",
    "Click on the link below to access it" : "Pincha en el enlace de abajo para tener acceso a esto",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Today" : "Hoy",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
    "Share Calendar" : "Compartir calendario",
    "Shared" : "Compartido",
    "More" : "Más",
    "Edit" : "Editar",
    "Link" : "Enlace",
    "iCal link" : "Enlace iCal",
    "Download" : "Descargar",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "can edit" : "puede editar",
    "Share link" : "Enlace compartido",
    "Public access" : "Acceso público",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "New Calendar" : "Nuevo calendario",
    "Name" : "Nombre",
    "New Subscription" : "Nueva suscripción",
    "Go back" : "Atrás",
    "Go forward" : "Adelante",
    "Calendar does not exist" : "El calendario no existe",
    "Maybe you got a wrong link or the calendar was unshared?" : "¿Quizás el enlace está equivocado o el calendario dejó de ser compartido?",
    "Edit event" : "Editar evento",
    "Delete Event" : "Eliminar evento",
    "Save Event" : "Guardar evento",
    "Time" : "Hora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Absoluto",
    "Repeat" : "Repetir",
    "times every" : "veces cada",
    "Add" : "Añadir",
    "Email address of attendee" : "Correo electrónico del asistente",
    "Please add your email address in the personal settings in order to add attendees." : "Por favor indique su correo electrónico en la configuración de su cuenta para agregar asistentes",
    "from" : "desde",
    "to" : "para",
    "This event's repeating rule is not supported yet." : "Esta regla de repetición de eventos aún no está soportada.",
    "Support for advanced rules will be added with subsequent updates." : "El soporte para reglas avanzadas se añadirá en próximas actualizaciones. ",
    "Reset repeating rule" : "Reinicializar regla de repetición",
    "Repeat every ..." : "Repetir cada ...",
    "end repeat ..." : "finalizar repetir ...",
    "times" : "veces",
    "Import Calendars" : "Importar calendario",
    "Import canceled" : "Importación cancelada",
    "Analyzing calendar" : "Analizando calendario",
    "The file contains objects incompatible with the selected calendar" : "El archivo contiene objetos incompatibles con el calendario seleccionado",
    "New calendar" : "Nuevo calendario",
    "File is empty" : "El archivo está vacío",
    "Import scheduled" : "Importar horario",
    "%s shared the calendar <strong>%s</strong> with you" : "%s compartió el calendario <strong>%s</strong> contigo",
    "Embed" : "Insertar",
    "Iframe to integrate" : "Iframe para integrar",
    "Publish URL" : "Publicar URL",
    "Settings & import" : "Ajustes & importar",
    "Skip simple event editor" : "Omitir el editor de evento único",
    "Show week numbers" : "Mostrar numero de semana",
    "Import calendar" : "Importar calendario",
    "No Calendars selected for import" : "No se seleccionó un calendario para importar",
    "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
    "iOS/OS X CalDAV address" : "Direccion de calendario CalDAV iOS/OSX",
    "Subscribe" : "Suscribirse"
},
"nplurals=2; plural=(n != 1);");
